@@ -833,7 +833,7 @@ class Connector(rsb.transport.Connector,
 
 
 class InPushConnector(Connector,
-                      rsb.transport.InConnector):
+                      rsb.transport.InPushConnector):
     """
     Instances of this class receive events from a bus (represented by
     a :obj:`Bus` object) that is accessed via a socket connection.
@@ -912,6 +912,9 @@ class TransportFactory(rsb.transport.TransportFactory):
     def createInPushConnector(self, converters, options):
         return InPushConnector(converters=converters, options=options)
 
+    def createInPullConnector(self, converters, options):
+        raise NotImplementedError()
+
     def createOutConnector(self, converters, options):
         return OutConnector(converters=converters, options=options)
 
